USCFC General Jurisdiction-Unreported | US Court of Federal Claims

Skip to main content
Site map

# USCFC General Jurisdiction-Unreported

U.S. Court of Federal Claims Opinions
Updated: 6 hours 33 min ago

General Jurisdiction (Reported) | General Jurisdiction (Unreported) | Vaccine (Reported) | Vaccine (Unreported) | Search for:

### 1:14-cv-00393 • TAYLOR v. USA

Filed 05/09/2014
UNREPORTED OPINION. granting Motion for Leave to Proceed in forma pauperis. Complaint is hereby dismissed with prejudice. The Clerk is directed to enter judgment. Signed by Judge Elaine D. Kaplan.

### 1:14-cv-00372 • MATTHEWS v. USA

Filed 05/09/2014
UNREPORTED OPINION: This court lacks jurisdiction over any claims raised by plaintiff's complaint. Accordingly, the complaint must be dismissed for lack of jurisdiction. The Clerk is directed to enter judgment. Motion for leave to proceed in forma pauperis is granted. Signed by Senior Judge Eric G. Bruggink.

### 1:13-cv-00720 • ALLEN ENGINEERING CONTRACTOR INC., v. USA

Filed 05/08/2014
UNREPORTED OPINION (Order): Granting Motion to Dismiss - Rule 12(b)(6); dismissing as moot [15] Motion for Summary Judgment and [24 ]Amended Motion for Summary Judgment; and the clerk is directed to enter judgment dismissing plaintiff's complaint. Signed by Senior Judge James F. Merow.

### 1:14-cv-00354 • SPACE EXPLORATION TECHNOLOGIES CORP. v. USA

Filed 05/08/2014
UNREPORTED ORDER granting Motion To Dissolve Preliminary Injunction [10]. Signed by Judge Susan G. Braden.

### 1:14-cv-00362 • WOLFE v. USA

Filed 05/08/2014
UNREPORTED OPINION and ORDER. The Clerk is directed to enter judgment. Signed by Judge Francis M. Allegra.

### 1:13-cv-00695 • ALLEN ENGINEERING CONTRACTOR INC., v. USA

Filed 05/08/2014
UNREPORTED OPINION (Order): granting Defendant's Motion to Dismiss - Rule 12(b)(6); dismissing as moot [8] Plaintiff's Motion for Summary Judgment and [19] Amended Motion for Summary Judgment. The Clerk is directed to enter judgment dismissing plaintiff's complaint. Signed by Senior Judge James F. Merow.

### 1:13-cv-00651 • HAWN v. USA

Filed 05/07/2014
UNREPORTED MEMORANDUM OPINION and ORDER granting Motion to Dismiss pursuant to Rule 12(b)(1). The Clerk is directed to enter judgment. No costs shall be awarded. Signed by Judge Victor J. Wolski.

### 1:12-cv-00057 • GROUND IMPROVEMENT TECHNIQUES, INC., et al v. USA

Filed 04/30/2014
UNREPORTED OPINION on MOTION to Substitute Party MOTION to Substitute Attorney Robert G. Barbour in place of Steven Schooley filed by GROUND IMPROVEMENT TECHNIQUES, INC., [48] denying Plaintiffs Ground Improvement Techniques, Inc. and MK-Ferguson Company Cross-Motion to Ratify Plaintiffs, filed June 7, 2013. Added attorney Robert Galen Barbour for GROUND IMPROVEMENT TECHNIQUES, INC.,,Robert Galen Barbour for MK FERGUSON COMPANY,,Robert Galen Barbour for SECURED PARTIES. Attorney Steven Roger Schooley terminated. The Clerks Office is directed to CORRECT the docket to reflect the substitution of the real parties in interest as plaintiffs, pursuant to RCFC 17(a)(3), as shown in the caption of this opinion; The Clerks Office is directed to SUBSTITUTE Mr. Robert G. Barbour, pursuant to RCFC 83.1(c)(4)(A)(i)(II), as the attorney of record for all plaintiffs in this case; and,Proceedings in this case, pursuant to the courts order of July 12, 2013, remain STAYED pending the resolution of the appeal before the Federal Circuit, and all provisions of that order remain in effect. Signed by Judge Lynn J. Bush.

Keywords: RCFC 17(a); Real Parties in Interest for Claims Transferred to Creditors in Bankruptcy Case; Neither Mandatory Nor Permissive Joinder UnderRules 19 and 20 Applies; Substitution of Real Parties in Interest and Counsel Granted.(TQ)

### 1:12-cv-00843 • NEVADA CONTROLS, LLC v. USA

Filed 04/29/2014
UNREPORTED ORDER denying Motion to Dismiss - Rule 12(b)(1) and (6). (Plaintiff's Amended Complaint due by 6/27/2014). Signed by Judge Elaine D. Kaplan.

### 1:09-cv-00815 • EAGLE et al

Filed 04/29/2014
UNREPORTED Order. Case is dismissed for failure to state a claim upon which relief can be granted pursuant to Rule 12(b)(6). No costs. The Clerk is directed to enter judgment. Signed by Judge Charles F. Lettow.

### 1:13-cv-00945 • WRIGHT v. USA

Filed 04/23/2014
UNREPORTED Memorandum Opinion and Order denying Motion to Appoint Counsel ; granting [16] Motion to Dismiss - Rule 12(b)(1). The Clerk is directed to enter judgment. Signed by Judge Susan G. Braden. Copy to parties.

### 1:13-cv-00975 • COLBERT v. USA

Filed 04/23/2014
UNREPORTED Memorandum Opinion and Final Order granting Motion to Dismiss - Rule 12(b)(1) and (6); and denying as moot [6] Motion to Strike, [8] Motion for Summary Judgment, and [10] Motion for Default. The Clerk is directed to enter judgment. In addition, plaintiff has thirty (30) days, pursuant to Rule 11(c)(3) of the Rules of the United States Court of Federal Claims, to show cause why the court should not issue an anti-filing injunction. If plaintiff does not do so, the Clerk will be further directed to accept no other actions or filings by Antonio Colbert, without an Order of the Chief Judge of the United States Court of Federal Claims. In the interim, the clerk's office shall reject any additional complaints from plaintiff unless accompanied by the court's required filing fee. Signed by Judge Susan G. Braden. (dls) Copy to parties. (USPS Tracking No. 9114 9010 7574 2690 0646 32)

### 1:14-cv-00286 • KABANDO v. USA

Filed 04/21/2014
UNREPORTED OPINION AND ORDER. The court GRANTS plaintiff's application to proceed in forma pauperis and DISMISSES plaintiff's complaint for lack of jurisdicition. Moreover, because the court lacks jurisdiction to hear plaintiff's claiUNREPORTED OPINION AND ORDER. The court GRANTS plaintiff's application to proceed in forma pauperis and DISMISSES plaintiff's complaint for lack of jurisdicition. Moreover, because the court lacks jurisdiction to hear plaintiff's claims, her ex parte motion for declaratory and injunctive relief is DENIED AS MOOT. The clerk is directed to enter judgment accordingly. The Clerk is directed to enter judgment. Signed by Judge Margaret M. Sweeney. (ac7) Copy to parties.ms, her ex parte motion for declaratory and injunctive relief is DENIED AS MOOT. The clerk is directed to enter judgment accordingly. The Clerk is directed to enter judgment. Signed by Judge Margaret M. Sweeney. (ac7) Copy to parties.

Keywords: Pro Se Plaintiff; Dismissal for Lack of Jurisdiction; Application to Proceed in Forma Pauperis.

### 1:14-cv-00247 • DAWVEED et al v. USA

Filed 04/16/2014
UNREPORTED OPINION dismissing plaintiffs' complaint for lack of jurisdiction.. The Clerk is directed to enter judgment. Signed by Judge Francis M. Allegra.

### 1:13-cv-00210 • SINGLETON ENTERPRISES v. USA

Filed 04/14/2014
UNREPORTED ORDER: Because the ASBCA has rendered its decision, the stay in this case is now lifted. Plaintiff is directed to file a motion to amend the complaint in this case such that it reads "Wayne Singleton, d/b/a Singleton Enterprises v. United States" no later than Friday, April 25, 2014. Then, the parties shall file no later than Friday, May 2, 2014 a joint status report suggesting further proceedings in this matter.Amended due by 4/25/2014. Status Report due by 5/2/2014. Signed by Judge Margaret M. Sweeney. (ac7) Copy to parties.

Keywords: Sole proprietorship. Alter ego. Independent legal status. Pro se. Personal capacity. Corporation.

### 1:05-cv-00914 • K-CON BUILDING SYSTEMS, INC., v. USA

Filed 04/14/2014
ORDER granting Motion to Strike [180] Amended Complaint. New Amended complaint due by 4/25/2014. Responsive pleading due by 5/9/2014. Response to any counterclaim due by 5/16/2014. Joint status report due by 5/23/2014. Signed by Judge Margaret M. Sweeney. (kb1)

Keywords: Motion to Strike; Amended Complaint.

### 1:13-cv-00664 • GIBSON v. USA

Filed 04/09/2014
UNREPORTED OPINION granting Motion to Dismiss - Rule 12(b)(1). The Clerk is directed to enter judgment. No costs. Signed by Judge Lynn J. Bush.

Keywords: Pro Se Complaint; RCFC 12(b)(1); No Jurisdiction to Review Denial of Workers' Compensation Benefits or to Collaterally Attack Judgments of a United States District Court.re: Unreported Opinion on Motion to Dismiss - Rule 12(b)(1).

### 1:13-cv-00393 • KC RESOURCES, INC. v. USA

Filed 04/09/2014
UNREPORTED OPINION granting Motion to Dismiss - Rule 12(b)(1) and (6). The Clerk is directed to enter judgment. Signed by Judge Edward J. Damich.

Keywords: re: Order on Motion to Dismiss - Rule 12(b)(1) and (6), Unreported Opinion: RCFC 12(b)(1), standing.

### 1:13-cv-00434 • U.S. HOME CORPORATION et al v. USA

Filed 04/08/2014
UNREPORTED OPINION. granting Motion to Dismiss - Rule 12(b)(1) and (6). The Clerk is directed to enter judgment. Signed by Judge Lynn J. Bush.

Keywords: Contracts; 28 U.S.C. § 2501 (2012); 28 U.S.C. § 1500(2012); Claims That Were Dismissed Because They Were Barred by Section 1500 Are Now Barred, in a Second Suit, by the Statute of Limitations inSection 2501. re: Order on Motion to Dismiss - Rule 12(b)(1) and (6), Unreported Opinion. (TQ)

### 1:14-cv-00040 • BANNUM, INC. v. USA

Filed 04/08/2014
UNREPORTED OPINION originally filed under seal on March 27, 2014. Signed by Judge Nancy B. Firestone. (sr) Copy to parties. Modified on 4/10/2014 - pdf(jt1).

Bid Protest; Lack of Standing; Failure to Submit a Responsive Bid; Prison Rape Elimination Act, 42 U.S.C. § 15602

## Pages

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9
- …
- next ›
- last »